==> magic3_1.7.25_src.tar.gz: magic3/widgets/admin_main/include/container/admin_mainResbrowseWidgetContainer.php <==
<?php
/**
 * コンテナクラス
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2007 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: admin_mainResbrowseWidgetContainer.php 1351 2008-12-14 10:02:05Z fishbone $
 * @link       http://www.magic3.org
 */
require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');

class admin_mainResbrowseWidgetContainer extends BaseWidgetContainer
{
	const FILE_BROWSER_PATH = '/fckeditor2.6/editor/plugins/FileBrowser_Thumbnail/browser.html?Lang=ja&Connector=connectors/php/connector.php';		// ファイルブラウザのパス
	
	/**
	 * コンストラクタ
	 */
	function __construct()
	{
		// 親クラスを呼び出す
		parent::__construct();
	}
	/**
	 * テンプレートファイルを設定
	 *
	 * _assign()でデータを埋め込むテンプレートファイルのファイル名を返す。
	 * 読み込むディレクトリは、「自ウィジェットディレクトリ/include/template」に固定。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。そのまま_assign()に渡る
	 * @return string 						テンプレートファイル名。テンプレートライブラリを使用しない場合は空文字列「''」を返す。
	 */
	function _setTemplate($request, &$param)
	{	
		return 'resbrowse.tmpl.html';
	}
	/**
	 * テンプレートにデータ埋め込む
	 *
	 * _setTemplate()で指定したテンプレートファイルにデータを埋め込む。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
	 * @param								なし
	 */
	function _assign($request, &$param)
	{
		$this->tmpl->addVar('_widget', 'root_url', $this->gEnv->getRootUrl());
		$this->tmpl->addVar('_widget', 'url', $this->gEnv->getScriptsUrl() . self::FILE_BROWSER_PATH);
	}
}
?>

==> magic3_1.8.1_src.tar.gz: magic3/widgets/admin_main/include/container/admin_mainResbrowseWidgetContainer.php <==
<?php
/**
 * コンテナクラス
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2009 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id: admin_mainResbrowseWidgetContainer.php 2142 2009-07-18 10:58:27Z fishbone $
 * @link       http://www.magic3.org
 */
require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_mainBrowseBaseWidgetContainer.php');

class admin_mainResbrowseWidgetContainer extends admin_mainBrowseBaseWidgetContainer
{
	const FILE_BROWSER_PATH = '/fckeditor2.6/editor/plugins/FileBrowser_Thumbnail/browser.html?Lang=ja&Connector=connectors/php/connector.php';		// ファイルブラウザのパス
	
	/**
	 * コンストラクタ
	 */
	function __construct()
	{
		// 親クラスを呼び出す
		parent::__construct();
	}
	/**
	 * テンプレートファイルを設定
	 *
	 * _assign()でデータを埋め込むテンプレートファイルのファイル名を返す。
	 * 読み込むディレクトリは、「自ウィジェットディレクトリ/include/template」に固定。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。そのまま_assign()に渡る
	 * @return string 						テンプレートファイル名。テンプレートライブラリを使用しない場合は空文字列「''」を返す。
	 */
	function _setTemplate($request, &$param)
	{	
		return 'resbrowse.tmpl.html';
	}
	/**
	 * テンプレートにデータ埋め込む
	 *
	 * _setTemplate()で指定したテンプレートファイルにデータを埋め込む。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
	 * @param								なし
	 */
	function _assign($request, &$param)
	{
		$this->tmpl->addVar('_widget', 'root_url', $this->gEnv->getRootUrl());
		$this->tmpl->addVar('_widget', 'url', $this->gEnv->getScriptsUrl() . self::FILE_BROWSER_PATH);
		$this->tmpl->addVar('_widget', 'res_dir', $this->gEnv->getResourcePath());// リソースディレクトリ
	}
}
?>
